Legoktm has uploaded a new change for review.

  https://gerrit.wikimedia.org/r/174986

Change subject: Move footer notice to header
......................................................................

Move footer notice to header

This brings us to be more consistent with ForeignFileRepo, which
places the notice on the top.

Change-Id: I6ec85547d6d49f1bb9a35effa8908c295f96462a
---
M GlobalUserPage.body.php
M GlobalUserPage.php
M ext.GlobalUserPage.css
M i18n/qqq.json
4 files changed, 14 insertions(+), 13 deletions(-)


  git pull ssh://gerrit.wikimedia.org:29418/mediawiki/extensions/GlobalUserPage 
refs/changes/86/174986/1

diff --git a/GlobalUserPage.body.php b/GlobalUserPage.body.php
index 3b02a30..96e2e72 100644
--- a/GlobalUserPage.body.php
+++ b/GlobalUserPage.body.php
@@ -48,17 +48,18 @@
                        parent::showMissingArticle();
                        return;
                }
-               $out->addHTML( $parsedOutput['text']['*'] );
-               $out->addModuleStyles( array( 'ext.GlobalUserPage', 
'ext.GlobalUserPage.site' ) );
 
-               $footerKey = $this->config->get( 'GlobalUserPageFooterKey' );
-               if ( $footerKey ) {
-                       $out->addHTML( '<div class="mw-globaluserpage-footer 
plainlinks">' .
-                               "\n" . $out->msg( $footerKey )
+               $headerKey = $this->config->get( 'GlobalUserPageHeaderKey' );
+               if ( $headerKey ) {
+                       $out->addHTML( '<div class="mw-globaluserpage-header 
plainlinks">' .
+                               "\n" . $out->msg( $headerKey )
                                        ->params( $this->getUsername(), 
$this->getRemoteURL() )->parse() .
                                "\n</div>"
                        );
                }
+               $out->addHTML( $parsedOutput['text']['*'] );
+               $out->addModuleStyles( array( 'ext.GlobalUserPage', 
'ext.GlobalUserPage.site' ) );
+
 
                // Load ParserOutput modules...
                $this->loadModules( $out, $parsedOutput );
diff --git a/ext.GlobalUserPage.css b/ext.GlobalUserPage.css
index 21d9763..878505f 100644
--- a/ext.GlobalUserPage.css
+++ b/ext.GlobalUserPage.css
@@ -2,7 +2,7 @@
        display: none;
 }
 
-.mw-globaluserpage-footer {
+.mw-globaluserpage-header {
        padding: 3px;
        border: 1px solid #aaa;
        font-size: 85%;
diff --git a/i18n/qqq.json b/i18n/qqq.json
index 36bd9df..b980f8b 100644
--- a/i18n/qqq.json
+++ b/i18n/qqq.json
@@ -7,5 +7,5 @@
        },
        "globaluserpage-desc": 
"{{desc|name=GlobalUserPage|url=https://www.mediawiki.org/wiki/Extension:GlobalUserPage}}";,
        "globaluserpage-preferences": "Used as checkbox label in 
[[Special:GlobalPreferences]].",
-       "globaluserpage-footer": "Footer shown on global user pages. 
Parameters:\n* $1 - the user's name\n* $2 - a link to the original user page on 
the central wiki"
+       "globaluserpage-footer": "Header shown on global user pages. 
Parameters:\n* $1 - the user's name\n* $2 - a link to the original user page on 
the central wiki"
 }

diff --git a/GlobalUserPage.php b/GlobalUserPage.php
index aedc73d..b5727b0 100644
--- a/GlobalUserPage.php
+++ b/GlobalUserPage.php
@@ -49,14 +49,14 @@
 $wgGlobalUserPageDBname = 'examplewiki';
 
 /**
  * Optionally add a footer message to the
  * bottom of every global user page. Should
  * be set to the name of a message key, or
  * false if no footer is wanted.
  *
  * @var string|bool
  */
-$wgGlobalUserPageFooterKey = 'globaluserpage-footer';
+$wgGlobalUserPageHeaderKey = 'globaluserpage-footer';
 
 /**
  * The name of the ResourceLoaderSource referring
@@ -80,7 +80,7 @@
 $wgExtensionCredits['other'][] = array(
        'path' => __FILE__,
        'name' => 'GlobalUserPage',
-       'version' => '0.10.0',
+       'version' => '0.11.0',
        'author' => array( 'Kunal Mehta', 'Jack Phoenix' ),
        'url' => 'https://www.mediawiki.org/wiki/Extension:GlobalUserPage',
        'descriptionmsg' => 'globaluserpage-desc',
@@ -49,14 +49,14 @@
 
 /**
- * Optionally add a footer message to the
- * bottom of every global user page. Should
+ * Optionally add a header message to the
+ * top of every global user page. Should
  * be set to the name of a message key, or
@@ -49,14 +49,14 @@
  * be set to the name of a message key, or
- * false if no footer is wanted.
+ * false if no header is wanted.
  *
  * @var string|bool
-- 
To view, visit https://gerrit.wikimedia.org/r/174986
To unsubscribe, visit https://gerrit.wikimedia.org/r/settings

Gerrit-MessageType: newchange
Gerrit-Change-Id: I6ec85547d6d49f1bb9a35effa8908c295f96462a
Gerrit-PatchSet: 1
Gerrit-Project: mediawiki/extensions/GlobalUserPage
Gerrit-Branch: master
Gerrit-Owner: Legoktm <legoktm.wikipe...@gmail.com>

_______________________________________________
MediaWiki-commits mailing list
MediaWiki-commits@lists.wikimedia.org
https://lists.wikimedia.org/mailman/listinfo/mediawiki-commits

Reply via email to